@@ -277,10 +277,10 @@ void expand_macro(int id, char **fmt, char **args[], struct log_info *msg)
 		break;
 	}
 	case 'f': {
-		int i = syslog_lookup_value(msg->pri & LOG_FACMASK, sl_facilities);
-		if (i != -1) {
+		char *n = syslog_lookup_value(msg->pri & LOG_FACMASK, sl_facilities);
+		if (n != NULL) {
 			ADD_MACRO_FMT("%z");
-			ADD_MACRO_ARG(sl_facilities[i].name);
+			ADD_MACRO_ARG(n);
 		}
 		else {
 			ADD_MACRO_FMT("0x%xi");
