@@ -269,11 +269,15 @@ do_init_afinet_source(struct log_handler *c,
 	case AFSOCKET_DGRAM: {
 		struct afsocket_source_connection *conn;
 		struct io_fd *client = make_io_fd(cfg->backend, fd);
+		int res;
 
 		self->super.num_connections = 1;
 		conn = make_afinet_source_connection(client, NULL, &self->super, self->super.super.super.next);
-		LOG_HANDLER_INIT(conn, cfg, NULL);
-
+		res = LOG_HANDLER_INIT(conn, cfg, NULL);
+		if ((res & ST_FAIL) == 0) {
+			conn->queue_node = 
+				object_queue_add_tail(self->super.connections, &conn->super.super.super);
+		}
 		break;
 	}
 	default:
