@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afstreams.c,v 1.7 1999/11/22 18:26:16 bazsi Exp $
+ * $Id: afstreams.c,v 1.8 1999/11/24 12:07:21 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -132,10 +132,11 @@ static void stream_read_callback(struct nonblocking_fd *fd)
 
 		bol = line;
 		eol = memchr(bol, '\n', n);
+		if (!eol) eol = memchr(bol, '\0', n);
 
 		while (eol) {
 
-			while (*bol <= 26) {
+			if (*bol == '\r') {
 				bol++;
 				n--;
 			}
@@ -150,7 +151,7 @@ static void stream_read_callback(struct nonblocking_fd *fd)
 			n -= length + 1;
 			bol = eol + 1;
 			eol = memchr(bol, '\n', n);
-
+			if (!eol) eol = memchr(bol, '\0', n);
 		}
 	}
 }
