@@ -44,11 +44,13 @@
 	(resources object resource_list)
         (backend object io_backend)
 	; global options
-	(long_hostnames simple UINT32)
+	(chain_hostnames simple UINT32)
 	(mark_freq simple UINT32)
 	(sync_freq simple UINT32)
 	(time_reopen simple UINT32)
 	(log_fifo_size simple UINT32)
+	(use_fqdn simple UINT32)
+	(use_dns simple UINT32)
 	; internal messages should come from this source
 	(internal object log_handler)
         (sources object log_source_group)
