@@ -36,6 +36,7 @@
 #include <errno.h>
 #include <string.h>
 #include <getopt.h>
+#include <wait.h>
 
 #include "main.c.x"
 
@@ -128,6 +129,13 @@ void sig_term(int signo)
 	signal(SIGTERM, sig_term);
 }
 
+void sig_child(int signo)
+{
+	while (waitpid(-1, NULL, WNOHANG) != -1)
+		;
+	signal(SIGCHLD, sig_child);
+}
+
 int main_loop(struct syslog_backend *backend)
 {
 	int exit_main_loop = 0;
@@ -135,6 +143,7 @@ int main_loop(struct syslog_backend *backend)
 	signal(SIGPIPE, SIG_IGN);
 	signal(SIGHUP, sig_hup);
 	signal(SIGTERM, sig_term);
+	signal(SIGCHLD, sig_child);
 
 	while (io_iter(&backend->super)) {
 		if (exit_main_loop)
@@ -175,7 +184,7 @@ void go_background()
 	
 	pid = fork();
 	if (pid == 0) {
-		int fd = open(pidfilename, O_CREAT | O_WRONLY | O_NOCTTY, 0666);
+		int fd = open(pidfilename, O_CREAT | O_WRONLY | O_NOCTTY | O_TRUNC, 0600);
 		if (fd != -1) {
 			struct ol_string *pid_s = c_format("%i", getpid());
 			write(fd, pid_s->data, pid_s->length);
@@ -235,7 +244,7 @@ int main(int argc, char **argv)
 #ifdef HAVE_MALLOPT
         mallopt(M_TOP_PAD, 0x10000);
 #endif
-/*	gc_threshold = 0;*/
+	gc_threshold = 1000;
 
 	while ((opt = getopt_long(argc, argv, "f:p:dvhy", syslog_ng_options, NULL)) != -1) {
 		switch (opt) {
