@@ -83,16 +83,16 @@ int syslog_lookup_name(const char *name, struct sl_name names[])
 	return -1;
 }
 
-int syslog_lookup_value(int value, struct sl_name names[])
+char *syslog_lookup_value(int value, struct sl_name names[])
 {
 	int i;
 
 	for (i = 0; names[i].name; i++) {
 		if (names[i].value == value) {
-			return i;
+			return names[i].name;
 		}
 	}
-	return -1;
+	return NULL;
 }
 
 UINT32 syslog_make_range(UINT32 r1, UINT32 r2)
